@@ -1,4 +1,4 @@
-'''
+"""
 Author:      www.tropofy.com
 
 Copyright 2013 Tropofy Pty Ltd, all rights reserved.
@@ -9,7 +9,7 @@ available at: http://www.tropofy.com/terms_of_service.html
 This source file is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
-'''
+"""
 
 import os
 import sys
@@ -21,19 +21,19 @@ from sqlalchemy import create_engine
 
 from tropofy.file_io import read_write_xl
 from data_set import AppDataSet
-from tropofy.widgets import DataSets, ExecuteFunction
+from tropofy.widgets import DataSets
 from tropofy.database import DBSession
 from tropofy.database.tropofy_orm import ORMBase, TropofyDbMetaData
 
 
 class App(object):
-
     global_app_indexer = 0
     overridden_global_sqla_engine = ''
 
-    def __init__(self):
+    def __init__(self, config):
         self.id = App.global_app_indexer
         App.global_app_indexer += 1
+        self.config = config
         self.name = self.get_name()
         self.url_name = make_safe_url_name(self.name)
         self.schema_name = None
@@ -110,6 +110,13 @@ class App(object):
             'content_row_4_col_1_content': ''
         }
 
+    def is_login_screen_default_create_account(self):
+        """At the login screen the default can be create account or sign in.
+
+        :rtype: bool
+        """
+        return True
+
     def get_published_license_key(self):
         return ''
 
@@ -204,8 +211,8 @@ class AppWithDataSets(App):
 
     """
 
-    def __init__(self):
-        App.__init__(self)
+    def __init__(self, config):
+        App.__init__(self, config)
 
     def _init_step_groups(self):
         self._add_data_sets_step_group()
@@ -378,7 +385,7 @@ class Parameter(object):
     :type default: Must comply with any restrictions imposed by the ``options``, ``validator``, and ``type`` parameters.
     :param options: (optional value restriction) An explicit list of values this parameter may take.
     :type options: list
-    :param type: (optional value restriction) Force the value to be this type. Otherwise raise an exception.
+    :param allowed_type: (optional value restriction) Force the value to be this type. Otherwise raise an exception.
     :type allowed_type: A Python Type. eg int, str, bool, dict, list
     :param validator: (optional value restriction) A function that provides custom validation of this parameter. Accepts a single param ``value`` and returns True for successful validation and a string explaining the error if not.
     :type validator: function
