@@ -46,11 +46,8 @@ class TaskMessage(object):
         self.text = text
         self.status = status
 
-    def serialise(self):
-        return {
-            'text': self.text,
-            'status': self.status,
-        }
+    def to_html(self):
+        return "<li class='text-%s'>%s</li>" % (self.status, self.text)
 
 
 class AppDataSet(ORMBase):
@@ -496,7 +493,7 @@ class TaskInterfaceMixin(object):
             'taskId': self.task_id,
             'dateTimeStartedStr': self.start_datetime,
             'elapsedSeconds': self.elapsed_seconds,
-            'progressMessageSpecs': [m.serialise() for m in self.messages],
+            'progressMessagesHtml': "".join([m.to_html() for m in self.messages[-200:]]),
             'isCurrentlyRunning': self.is_currently_running,
             'status': self.status,
             'taskCanBeTerminated': self.task_can_be_terminated(),
@@ -642,11 +639,11 @@ class SynchronousTask(DataSetMixin, TaskInterfaceMixin):
         return self._is_currently_running
 
     def track_task_finished(self, execution_success, exception=None):
-        self.end_datetime = datetime.now()
-        self._is_currently_running = False
-        self._status = TaskInterfaceMixin.SUCCESS if execution_success else TaskInterfaceMixin.FAILURE
         if not execution_success and str(exception):
-            self._messages.append(TaskMessage(text="%s: %s" % (type(exception).__name__, str(exception)), status=TaskMessage.ERROR))
+            self.add_messages([TaskMessage(text="%s: %s" % (type(exception).__name__, str(exception)), status=TaskMessage.ERROR)])
+        self.end_datetime = datetime.now()
+        self._status = TaskInterfaceMixin.SUCCESS if execution_success else TaskInterfaceMixin.FAILURE
+        self._is_currently_running = False
 
     def add_messages(self, messages):
         self._messages = self._messages + messages
