@@ -2,6 +2,7 @@ from celery.signals import celeryd_init, task_prerun, task_postrun, before_task_
 from celery import current_task
 from sqlalchemy import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker
+from sqlalchemy.orm.exc import NoResultFound
 from tropofy.database.tropofy_orm import DynamicSchemaName
 
 
@@ -87,10 +88,11 @@ def task_prerun_handler(sender=None, body=None, **kwargs):
 @task_postrun.connect()
 def task_postrun_handler(sender=None, body=None, **kwargs):
     """Finalises task, ensuring that the connection to the database is closed and commited/rolled back as appropriate on task completion."""
-    celery_task = _get_celery_task_from_handler_kwargs(kwargs)
     finished_status = kwargs['state']
     task_successful = finished_status == CeleryTask.SUCCESS
 
+    celery_task = _get_celery_task_from_handler_kwargs(kwargs)
+
     if not task_successful:
         AppDataSet.db_session.rollback()
 
@@ -115,4 +117,4 @@ def _get_celery_task_from_handler_kwargs(kwargs):
             if type(arg) is AppDataSet:
                 data_set = arg
                 break
-    return data_set.query(CeleryTask).filter_by(task_id=task_id).first()
\ No newline at end of file
+    return data_set.query(CeleryTask).filter_by(task_id=task_id).one()
\ No newline at end of file
