@@ -71,7 +71,7 @@ def run_app(request):
 def redirect_to_run_app(request):
     if request.only_app:
         return exc.HTTPFound(
-            location=request.route_url('run_app', app_url_name=request.only_app.url_name, _scheme=request.scheme, _port=request.server_port)  # Must specify port if specify scheme - otherwise breaks
+            location=request.route_url('run_app', app_url_name=request.only_app.url_name)  # Must specify port if specify scheme - otherwise breaks
         )
     else:
         raise exc.HTTPNotFound()
@@ -191,7 +191,7 @@ def logout(request):
 @forbidden_view_config(renderer='string')
 def forbidden(request):
     return exc.HTTPFound(
-        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'), _scheme=request.scheme, _port=request.server_port)
+        location=request.route_url('logout', app_url_name=request.matchdict.get('app_url_name'))
     )
 
 
