@@ -21,6 +21,7 @@ from celery.task.control import inspect
 from celery.task.control import revoke
 from tropofy.app.data_set import CeleryTask
 import collections
+import transaction
 
 
 class ExecuteFunction(Widget):
@@ -79,7 +80,7 @@ class ExecuteFunction(Widget):
         try:
             synchronousTask = data_set.query(SynchronousTask).filter_by(id=task_id).one()
         except exc.NoResultFound:
-            pass  # Synchronous task not initialised correctly. Please try again and if problems persists, you may need to refresh the page.
+            print("Synchronous task not initialised correctly. Please try again and if problems persists, you may need to refresh the page.")  # TODO: Make better than print statement?
             return
         try:
             data_set._running_task = synchronousTask
@@ -88,6 +89,8 @@ class ExecuteFunction(Widget):
             # data_set._running_task = None
         except Exception as e:
             print(traceback.format_exc())
+            transaction.abort()
+            synchronousTask = data_set.query(SynchronousTask).filter_by(id=task_id).one()
             synchronousTask.track_task_finished(execution_success=False, exception=e)
 
     def _start_celery_tasks(self, data_set):
